@@ -175,7 +175,7 @@ def sync_static(config, args):
         log.debug('makedirs %s' % config.html_dir)
         os.makedirs(config.html_dir)
     
-    command = ('rsync -vaxq --ignore-errors --exclude=.* --exclude=_*').split()
+    command = ('rsync -vaxq --ignore-errors --include=.htaccess --exclude=.* --exclude=_*').split()
     display_cmd = command[:]
     
     if config['use-default-static']:
@@ -207,7 +207,7 @@ def sync_html(config, args):
         log.debug('makedirs %s' % config.html_dir)
         os.makedirs(config.html_dir)
     
-    command = ('rsync -vaxq --delete --ignore-errors --exclude=.* --exclude=_*').split()
+    command = ('rsync -vaxq --delete --ignore-errors --include=.htaccess --exclude=.* --exclude=_*').split()
     display_cmd = command[:]
     
     # rsync needs the paths to have trailing slashes to work correctly.
